Sets
====

Set Constructions
-----------------

.. toctree::
   :maxdepth: 1

   sage/sets/cartesian_product
   sage/sets/family
   sage/sets/set
   sage/sets/disjoint_set
   sage/sets/disjoint_union_enumerated_sets
   sage/sets/set_from_iterator
   sage/sets/finite_enumerated_set
   sage/sets/recursively_enumerated_set
   sage/sets/condition_set
   sage/sets/finite_set_maps
   sage/sets/finite_set_map_cy
   sage/sets/totally_ordered_finite_set
   sage/sets/pythonclass

Sets of Numbers
---------------

.. toctree::
   :maxdepth: 1

   sage/sets/integer_range
   sage/sets/positive_integers
   sage/sets/non_negative_integers
   sage/sets/primes
   sage/sets/real_set

.. include:: ../footer.txt
